Crate codex_uds

Crate codex_uds 

Cross-platform async Unix domain socket helpers.

Structs

UnixListener
Async Unix domain socket listener.
UnixStream
Async Unix domain socket stream.

Functions

is_stale_socket_path
Returns whether socket_path points at a stale Unix socket rendezvous path.
prepare_private_socket_directory
Creates socket_dir if needed and restricts it to the current user where the platform exposes Unix permissions.